@@ -20,7 +20,7 @@
 # config auxdir.
 # Keep this in sync with sister tests auxdir7.test and auxdir8.test.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat > configure.ac <<END
 AC_INIT([$me], [1.0])
