@@ -18,7 +18,7 @@
 #  - even after a "Bail out!" directive, all input is still copied in
 #    the log file
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 . "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
 
@@ -31,7 +31,7 @@ non-TAP line after bailout
 ok 1 - TAP result after bailout
 END
 
-$MAKE check && { cat all.log; Exit 1; }
+$MAKE check && { cat all.log; exit 1; }
 cat all.log
 
 for rx in \
