@@ -19,7 +19,7 @@
 #    plan, then the driver reports both "missing plan" and "exited with
 #    non-zero status" errors.
 
-. ./defs || Exit 1
+. ./defs || exit 1
 
 cat > foo.test <<END
 #!/bin/sh
@@ -32,7 +32,7 @@ chmod a+x foo.test
 
 . "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
 
-$MAKE check >stdout && { cat stdout; Exit 1; }
+$MAKE check >stdout && { cat stdout; exit 1; }
 cat stdout
 count_test_results total=2 pass=0 fail=0 xpass=0 xfail=0 skip=0 error=2
 
